#!/bin/bash

set -euo pipefail

SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
PROJECT_DIR="$(dirname "$SCRIPT_DIR")"

echo "Building and running unit tests for getpkg multi-server support..."

# Create a temporary Dockerfile for building tests
cat > "$SCRIPT_DIR/Dockerfile.test-build" << 'EOF'
FROM gitea.jde.nz/public/dropshell-build-base:latest

# Copy source files
COPY . /app/

# Set working directory
WORKDIR /app/test

# Build tests
RUN cmake -G Ninja -S . -B ./build -DCMAKE_BUILD_TYPE=Debug -DCMAKE_PREFIX_PATH=/usr/local
RUN cmake --build ./build

# Run tests
CMD ["./build/getpkg_tests"]
EOF

echo "Building test container..."
docker build -t getpkg-test-build -f "$SCRIPT_DIR/Dockerfile.test-build" "$PROJECT_DIR"

echo "Running unit tests..."
docker run --rm getpkg-test-build

echo "Cleaning up..."
rm -f "$SCRIPT_DIR/Dockerfile.test-build"

echo "Unit tests completed!"